summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--alloca.c6
1 files changed, 5 insertions, 1 deletions
diff --git a/alloca.c b/alloca.c
index 16f19a2..367b7fe 100644
--- a/alloca.c
+++ b/alloca.c
@@ -25,7 +25,10 @@
#include "config.h"
#endif
-/* If compiling with GCC, this file's not needed. */
+/* If compiling with GCC 2, this file's not needed. */
+#if defined (__GNUC__) && __GNUC__ >= 2
+/* If someone has defined alloca as a macro,
+ there must be some other way alloca is supposed to work. */
#ifndef alloca
#ifdef emacs
@@ -473,3 +476,4 @@ i00afunc (long address)
#endif /* CRAY */
#endif /* no alloca */
+#endif /* not GCC version 2 */